/* Generated by Font Squirrel (http://www.fontsquirrel.com) on February 4, 2016 */



@font-face {
    font-family: 'open_sansbold';
    src: url('../fonts/opensans-bold.eot');
    src: url('../fonts/opensans-bold.eot?#iefix') format('embedded-opentype'),
         url('../fonts/opensans-bold.woff2') format('woff2'),
         url('../fonts/opensans-bold.woff') format('woff'),
         url('../fonts/opensans-bold.ttf') format('truetype'),
         url('../fonts/opensans-bold.svg#open_sansbold') format('svg');
    font-weight: normal;
    font-style: normal;

}




@font-face {
    font-family: 'open_sanslight';
    src: url('../fonts/opensans-light.eot');
    src: url('../fonts/opensans-light.eot?#iefix') format('embedded-opentype'),
         url('../fonts/opensans-light.woff2') format('woff2'),
         url('../fonts/opensans-light.woff') format('woff'),
         url('../fonts/opensans-light.ttf') format('truetype'),
         url('../fonts/opensans-light.svg#open_sanslight') format('svg');
    font-weight: normal;
    font-style: normal;

}




@font-face {
    font-family: 'open_sanslight_italic';
    src: url('../fonts/opensans-lightitalic.eot');
    src: url('../fonts/opensans-lightitalic.eot?#iefix') format('embedded-opentype'),
         url('../fonts/opensans-lightitalic.woff2') format('woff2'),
         url('../fonts/opensans-lightitalic.woff') format('woff'),
         url('../fonts/opensans-lightitalic.ttf') format('truetype'),
         url('../fonts/opensans-lightitalic.svg#open_sanslight_italic') format('svg');
    font-weight: normal;
    font-style: normal;

}




@font-face {
    font-family: 'open_sansregular';
    src: url('../fonts/opensans-regular.eot');
    src: url('../fonts/opensans-regular.eot?#iefix') format('embedded-opentype'),
         url('../fonts/opensans-regular.woff2') format('woff2'),
         url('../fonts/opensans-regular.woff') format('woff'),
         url('../fonts/opensans-regular.ttf') format('truetype'),
         url('../fonts/opensans-regular.svg#open_sansregular') format('svg');
    font-weight: normal;
    font-style: normal;

}