@font-face {
    font-family: 'nexa_boldregular';
    src: url('../fonts/nexa_bold.eot');
    src: url('../fonts/nexa_bold.eot?#iefix') format('embedded-opentype'),
         url('../fonts/nexa_bold.woff2') format('woff2'),
         url('../fonts/nexa_bold.woff') format('woff'),
         url('../fonts/nexa_bold.ttf') format('truetype'),
         url('../fonts/nexa_bold.svg#nexa_boldregular') format('svg');
    font-weight: normal;
    font-style: normal;

}




@font-face {
    font-family: 'nexa_lightregular';
    src: url('../fonts/nexa_light.eot');
    src: url('../fonts/nexa_light.eot?#iefix') format('embedded-opentype'),
         url('../fonts/nexa_light.woff2') format('woff2'),
         url('../fonts/nexa_light.woff') format('woff'),
         url('../fonts/nexa_light.ttf') format('truetype'),
         url('../fonts/nexa_light.svg#nexa_lightregular') format('svg');
    font-weight: normal;
    font-style: normal;

}